<template>
    <div class="dialog-table-container">
        <el-table
            row-key="id"
            height="65vh"
            align="center"
            :data="tableData"
            class="dialog_table"
            :cell-style="{'text-align': 'center'}"
            :header-cell-style="{'text-align': 'center'}"
        >
            <el-table-column type="expand" label="点击查看详情" width="140">
                <template slot-scope="props">
                    <el-form label-position="top" class="dialog-table-expand">
                        <el-row>
                            <el-form-item label="推进详情：">
                                <span>{{ props.row.propulsiveDetailed }}</span>
                            </el-form-item>
                        </el-row>
                        <el-row>
                            <el-form-item label="存在问题：">
                                <span>{{ props.row.existingProblems }}</span>
                            </el-form-item>
                        </el-row>
                    </el-form>
                </template>
            </el-table-column>
            <el-table-column
                prop="blockageCardTopic"
                label="堵点卡点名称"
                width="180"
            >
            </el-table-column>
            <el-table-column prop="blockageSourceChannel" label="来源渠道">
                <template v-slot="{row}">
                    {{ getDictName('ddkdlyqd', row.blockageSourceChannel) }}
                </template>
            </el-table-column>
            <el-table-column prop="blockageField" label="所属领域">
                <template v-slot="{row}">
                    {{ getDictName('ggbb_ssly', row.blockageField) }}
                </template>
            </el-table-column>
            <el-table-column prop="blockageRunway" label="所属跑道">
                <template v-slot="{row}">
                    {{ getDictName('ggbb_sspd', row.blockageRunway) }}
                </template>
            </el-table-column>
            <el-table-column prop="blockageDate" label="出现日期" width="100">
            </el-table-column>
            <el-table-column
                prop="feedbackTimeLimit"
                label="反馈时限"
            ></el-table-column>
            <el-table-column
                prop="propulsiveStatus"
                label="推进状态"
            ></el-table-column>
        </el-table>
        <pagenation
            :pageResult="prarms.pageBean"
            @currentChange="pageChange"
            class="pagenation"
        ></pagenation>
    </div>
</template>

  <script>
import utils from '@/utils.js'
import pagenation from './pagenation.vue'
import apiList from '@/api/bigScreen/districView.js'
export default {
    components: {pagenation},
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            tableData: [],
            prarms: {
                pageBean: {
                    page: 1,
                    pageSize: 10,
                    total: 0,
                    showTotal: true,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'a.BLOCKAGE_YEAR_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LESS_EQUAL',
                        parentGroup: '',
                        property: 'a.BLOCKAGE_QUARTER_', // 字段名
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'a.UNIT_CODE_', // 字段名
                        relation: 'AND',
                        value: '',
                    },
                ],
            },
        }
    },
    mounted() {
        this.querysParams = this.$route.query
        let {code} = this.querysParams
        let {quarter, year} = this.tableOptions
        this.loadData(code, quarter, year)
    },
    methods: {
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        loadData(code, quarter, year) {
            this.loading = true
            this.prarms.querys[0].value = year
            this.prarms.querys[1].value = quarter
            this.prarms.querys[2].value = code
            // let searchDate = sessionStorage.getItem('searchDate')
            // searchDate = JSON.parse(searchDate)
            // this.prarms.querys[1].value = searchDate.year
            // this.prarms.querys[2].value = searchDate.quarter
            apiList.problemSolvingDetail(this.prarms, (res) => {
                console.log(res)
                if (res && res.rows) {
                    this.tableData = res.rows
                    this.prarms.pageBean.page = res.page
                    this.prarms.pageBean.pageSize = res.pageSize
                    this.prarms.pageBean.total = res.total
                }
                this.loading = false
            })
        },
        pageChange(key) {
            let {code} = this.querysParams
            let {quarter, year} = this.tableOptions
            this.params.pageBean.page = key
            this.loadData(code, quarter, year)
        },
        expandChange(row, expandedRows) {
            console.log(row, expandedRows)
        },
    },
}
</script>
<style lang="scss" scoped>
/deep/ .dialog-table-expand label {
    width: 120px;
    color: #fff;
    font-family: SimHei;
}
/deep/ .el-input__inner {
    background-color: rgba(1, 47, 115, 0.6);
    border: 1px solid #0273E9;
    color: #fff;
}
</style>
<style lang="scss">
@import './table.scss';
</style>
